/**
 * @file drawtext.c
 * @brief Functions to draw text into yu'sv images
 * @author Florian Schmitt (0schmitt@informatik.uni-hamburg.de)
 * @date Sep-2012
**/
#include "camcapture.h"

#define CHAR_LINES    7
#define CHAR_COLS     5
#define CHAR_CNT     71

/* Here comes the character table */
const char chars[CHAR_CNT][CHAR_LINES*CHAR_COLS] =
	{
		/* Unknown/NUL (ascii 000) */
		{
			1, 1, 1, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 1, 1, 1, 0
		},
		/* Space (ascii 032) */
		{
			0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0
		},
		/* ! (ascii 033) */
		{
			0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 0, 0, 0
		},
		/* " (ascii 034) */
		{
			0, 1, 0, 1, 0,
		 	0, 1, 0, 1, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0
		},
		/* # (ascii 035) */
		{
			0, 1, 0, 1, 0,
		 	1, 1, 1, 1, 1,
		 	0, 1, 0, 1, 0,
		 	0, 1, 0, 1, 0,
		 	0, 1, 0, 1, 0,
		 	1, 1, 1, 1, 1,
		 	0, 1, 0, 1, 0
		},
		/* $ (ascii 036) */
		{
			0, 0, 1, 0, 0,
		 	0, 1, 1, 1, 0,
		 	1, 0, 1, 0, 0,
		 	0, 1, 1, 0, 0,
		 	0, 0, 1, 1, 0,
		 	1, 1, 1, 0, 0,
		 	0, 0, 1, 0, 0
		},
		/* % (ascii 037) */
		{
			1, 1, 0, 1, 0,
		 	1, 1, 0, 1, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 1, 0, 0, 0,
		 	1, 0, 1, 1, 0,
		 	1, 0, 1, 1, 0
		},
		/* & (ascii 038) */
		{
			0, 1, 1, 0, 0,
			1, 0, 1, 0, 0,
			1, 0, 1, 0, 0,
			1, 1, 0, 0, 0,
			1, 0, 1, 1, 0,
			1, 0, 1, 0, 0,
			0, 1, 0, 1, 0
		},
		/* empty (ascii 039) */
		{
			0, 0, 0, 0, 0,
			0, 0, 0, 0, 0,
			0, 0, 0, 0, 0,
			0, 0, 0, 0, 0,
			0, 0, 0, 0, 0,
			0, 0, 0, 0, 0,
			0, 0, 0, 0, 0
		},
		/* ( (ascii 040) */
		{
			0, 0, 1, 0, 0,
		 	0, 1, 0, 0, 0,
		 	0, 1, 0, 0, 0,
		 	0, 1, 0, 0, 0,
		 	0, 1, 0, 0, 0,
		 	0, 1, 0, 0, 0,
		 	0, 0, 1, 0, 0
		},
		/* ) (ascii 041) */
		{
			0, 1, 0, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 1, 0, 0, 0
		},
		/* * (ascii 042) */
		{
			0, 1, 0, 1, 0,
		 	0, 0, 1, 0, 0,
		 	0, 1, 0, 1, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0
		},
		/* + (ascii 043) */
		{
			0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	1, 1, 1, 1, 1,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0
		},
		/* , (ascii 044) */
		{
			0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 1, 0,
		 	0, 0, 1, 0, 0
		},
		/* - (ascii 045) */
		{
			0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 1, 1, 1, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0
		},
		/* . (ascii 046) */
		{
			0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 1, 0,
		 	0, 0, 0, 1, 0
		},
		/*  (ascii 047) */
		{
			0, 0, 0, 1, 0,
		 	0, 0, 0, 1, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 1, 0, 0, 0,
		 	0, 1, 0, 0, 0,
		 	1, 0, 0, 0, 0
		},
		/* 0 (ascii 048) */
		{
			0, 1, 1, 0, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 1, 1, 0,
		 	1, 1, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	0, 1, 1, 0, 0
		},
		/* 1 (ascii 049) */
		{
			0, 0, 0, 1, 0,
		 	0, 0, 1, 1, 0,
		 	0, 1, 0, 1, 0,
		 	0, 0, 0, 1, 0,
		 	0, 0, 0, 1, 0,
		 	0, 0, 0, 1, 0,
		 	0, 0, 0, 1, 0
		},
		/* 2 (ascii 050) */
		{
			0, 1, 1, 0, 0,
		 	1, 0, 0, 1, 0,
		 	0, 0, 0, 1, 0,
		 	0, 1, 1, 0, 0,
		 	1, 0, 0, 0, 0,
		 	1, 0, 0, 0, 0,
		 	1, 1, 1, 1, 0
		},
		/* 3 (ascii 051) */
		{
			0, 1, 1, 0, 0,
		 	1, 0, 0, 1, 0,
		 	0, 0, 0, 1, 0,
		 	0, 1, 1, 0, 0,
		 	0, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	0, 1, 1, 0, 0
		},
		/* 4 (ascii 052) */
		{
			0, 0, 1, 0, 0,
		 	0, 1, 1, 0, 0,
		 	1, 0, 1, 0, 0,
		 	1, 0, 1, 0, 0,
		 	1, 1, 1, 1, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0
		},
		/* 5 (ascii 053) */
		{
			1, 1, 1, 1, 0,
		 	1, 0, 0, 0, 0,
		 	1, 0, 0, 0, 0,
		 	0, 1, 1, 0, 0,
		 	0, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	0, 1, 1, 0, 0
		},
		/* 6 (ascii 054) */
		{
			0, 1, 1, 0, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 0, 0,
		 	1, 1, 1, 0, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	0, 1, 1, 0, 0
		},
		/* 7 (ascii 055) */
		{
			1, 1, 1, 1, 0,
		 	0, 0, 0, 1, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 1, 0, 0, 0,
		 	0, 1, 0, 0, 0,
		 	0, 1, 0, 0, 0
		},
		/* 8 (ascii 056) */
		{
			0, 1, 1, 0, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	0, 1, 1, 0, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	0, 1, 1, 0, 0
		},
		/* 9 (ascii 057) */
		{
			0, 1, 1, 0, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	0, 1, 1, 0, 0,
		 	0, 0, 0, 1, 0,
		 	0, 0, 0, 1, 0,
		 	0, 1, 1, 0, 0
		},
		/* : (ascii 058) */
		{
			0, 0, 0, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0
		},
		/* ; (ascii 059) */
		{
			0, 0, 0, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 1, 0, 0, 0
		},
		/* < (ascii 060) */
		{
			0, 0, 0, 1, 0,
		 	0, 0, 1, 0, 0,
		 	0, 1, 0, 0, 0,
		 	1, 0, 0, 0, 0,
		 	0, 1, 0, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 0, 1, 0
		},
		/* = (ascii 061) */
		{
			0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	1, 1, 1, 1, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	1, 1, 1, 1, 0,
		 	0, 0, 0, 0, 0
		},
		/* > (ascii 062) */
		{
			1, 0, 0, 0, 0,
		 	0, 1, 0, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 0, 1, 0,
		 	0, 0, 1, 0, 0,
		 	0, 1, 0, 0, 0,
		 	1, 0, 0, 0, 0
		},
		/* ? (ascii 063) */
		{
			0, 0, 1, 0, 0,
		 	0, 1, 0, 1, 0,
		 	0, 0, 0, 1, 0,
		 	0, 0, 0, 1, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 1, 0, 0
		},
		/* @ (ascii 064) */
		{
			0, 1, 1, 0, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 1, 0, 1, 0,
		 	1, 0, 1, 1, 0,
		 	1, 0, 0, 0, 1,
		 	0, 1, 1, 1, 0
		},
		/* A (ascii 065) */
		{
			0, 1, 1, 0, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 1, 1, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0
		},
		/* B */
		{
			1, 1, 1, 0, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 1, 1, 0, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 1, 1, 0, 0
		},
		/* C */
		{
			0, 1, 1, 0, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 0, 0,
		 	1, 0, 0, 0, 0,
		 	1, 0, 0, 0, 0,
		 	1, 0, 0, 1, 0,
		 	0, 1, 1, 0, 0
		},
		/* D */
		{
			1, 1, 0, 0, 0,
		 	1, 0, 1, 0, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 1, 0, 0,
		 	1, 1, 0, 0, 0
		},
		/* E */
		{
			1, 1, 1, 1, 0,
		 	1, 0, 0, 0, 0,
		 	1, 0, 0, 0, 0,
		 	1, 1, 1, 1, 0,
		 	1, 0, 0, 0, 0,
		 	1, 0, 0, 0, 0,
		 	1, 1, 1, 1, 0
		},
		/* G */
		{
			1, 1, 1, 1, 0,
		 	1, 0, 0, 0, 0,
		 	1, 0, 0, 0, 0,
		 	1, 1, 1, 0, 0,
		 	1, 0, 0, 0, 0,
		 	1, 0, 0, 0, 0,
		 	1, 0, 0, 0, 0
		},
		/* G */
		{
			0, 1, 1, 0, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 0, 0,
		 	1, 0, 1, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	0, 1, 1, 0, 0
		},
		/* H */
		{
			1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 1, 1, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0
		},
		/* I */
		{
			0, 1, 1, 1, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 1, 1, 1, 0
		},
		/* J */
		{
			0, 1, 1, 1, 0,
		 	0, 0, 0, 1, 0,
		 	0, 0, 0, 1, 0,
		 	0, 0, 0, 1, 0,
		 	0, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	0, 1, 1, 0, 0
		},
		/* K */
		{
			1, 0, 0, 1, 0,
		 	1, 0, 1, 0, 0,
		 	1, 1, 0, 0, 0,
		 	1, 1, 0, 0, 0,
		 	1, 0, 1, 0, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0
		},
		/* L */
		{
			1, 0, 0, 0, 0,
		 	1, 0, 0, 0, 0,
		 	1, 0, 0, 0, 0,
		 	1, 0, 0, 0, 0,
		 	1, 0, 0, 0, 0,
		 	1, 0, 0, 0, 0,
		 	1, 1, 1, 1, 0
		},
		/* M */
		{
			1, 0, 0, 0, 1,
		 	1, 1, 0, 1, 1,
		 	1, 0, 1, 0, 1,
		 	1, 0, 0, 0, 1,
		 	1, 0, 0, 0, 1,
		 	1, 0, 0, 0, 1,
		 	1, 0, 0, 0, 1
		},
		/* N */
		{
			1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 1, 0, 1, 0,
		 	1, 0, 1, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0
		},
		/* O */
		{
			0, 1, 1, 0, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	0, 1, 1, 0, 0
		},
		/* P */
		{
			1, 1, 1, 0, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 1, 1, 0, 0,
		 	1, 0, 0, 0, 0,
		 	1, 0, 0, 0, 0,
		 	1, 0, 0, 0, 0
		},
		/* Q */
		{
			0, 1, 1, 0, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 1, 0, 0,
		 	0, 1, 0, 1, 0
		},
		/* R */
		{
			1, 1, 1, 0, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 1, 1, 0, 0,
		 	1, 1, 0, 0, 0,
		 	1, 0, 1, 0, 0,
		 	1, 0, 0, 1, 0
		},
		/* S */
		{
			0, 1, 1, 1, 0,
		 	1, 0, 0, 0, 0,
		 	1, 0, 0, 0, 0,
		 	0, 1, 1, 0, 0,
		 	0, 0, 0, 1, 0,
		 	0, 0, 0, 1, 0,
		 	1, 1, 1, 0, 0
		},
		/* T */
		{
			1, 1, 1, 1, 1,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0
		},
		/* U */
		{
			1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	0, 1, 1, 0, 0
		},
		/* V */
		{
			0, 1, 0, 1, 0,
		 	0, 1, 0, 1, 0,
		 	0, 1, 0, 1, 0,
		 	0, 1, 0, 1, 0,
		 	0, 1, 0, 1, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0
		},
		/* W */
		{
			1, 0, 0, 0, 1,
		 	1, 0, 0, 0, 1,
		 	1, 0, 0, 0, 1,
		 	1, 0, 1, 0, 1,
		 	1, 0, 1, 0, 1,
		 	1, 0, 1, 0, 1,
		 	0, 1, 0, 1, 0
		},
		/* X */
		{
			1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	0, 1, 1, 0, 0,
		 	0, 1, 1, 0, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0,
		 	1, 0, 0, 1, 0
		},
		/* Y */
		{
			0, 1, 0, 1, 0,
		 	0, 1, 0, 1, 0,
		 	0, 1, 0, 1, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0
		},
		/* Z (ascii 090) */
		{
			1, 1, 1, 1, 0,
		 	0, 0, 0, 1, 0,
		 	0, 0, 1, 0, 0,
		 	0, 1, 0, 0, 0,
		 	1, 0, 0, 0, 0,
		 	1, 0, 0, 0, 0,
		 	0, 1, 1, 1, 0
		},
		/* [ (ascii 091) */
		{
			0, 1, 1, 0, 0,
		 	0, 1, 0, 0, 0,
		 	0, 1, 0, 0, 0,
		 	0, 1, 0, 0, 0,
		 	0, 1, 0, 0, 0,
		 	0, 1, 0, 0, 0,
		 	0, 1, 1, 0, 0
		},
		/* \ (ascii 092) */
		{
			1, 0, 0, 0, 0,
		 	0, 1, 0, 0, 0,
		 	0, 1, 0, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 0, 1, 0,
		 	0, 0, 0, 1, 0
		},
		/* ] (ascii 093) */
		{
			0, 1, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 1, 1, 0, 0
		},
		/* ^ (ascii 094) */
		{
			0, 0, 1, 0, 0,
		 	0, 1, 0, 1, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0
		},
		/* _ (ascii 095) */
		{
			0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	1, 1, 1, 1, 0
		},
		/* ` (ascii 096) */
		{
			0, 1, 0, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0
		},
		/* { (ascii 123) */
		{
			0, 0, 1, 0, 0,
		 	0, 1, 0, 0, 0,
		 	0, 1, 0, 0, 0,
		 	1, 0, 0, 0, 0,
		 	0, 1, 0, 0, 0,
		 	0, 1, 0, 0, 0,
		 	0, 0, 1, 0, 0
		},
		/* | (ascii 124) */
		{
			0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0
		},
		/* } (ascii 125) */
		{
			0, 1, 0, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 0, 1, 0,
		 	0, 0, 1, 0, 0,
		 	0, 0, 1, 0, 0,
		 	0, 1, 0, 0, 0
		},
		/* ~ (ascii 126) */
		{
			0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0,
		 	0, 1, 0, 0, 0,
		 	1, 0, 1, 0, 1,
		 	0, 0, 0, 1, 0,
		 	0, 0, 0, 0, 0,
		 	0, 0, 0, 0, 0
		},
		/* ? */
		{
			1, 1, 1, 1, 1,
		 	1, 1, 1, 1, 1,
		 	1, 1, 1, 1, 1,
		 	1, 1, 1, 1, 1,
		 	1, 1, 1, 1, 1,
		 	1, 1, 1, 1, 1,
		 	1, 1, 1, 1, 1
		}
	};




/**
 * Convert ASCII-Char to our char-table
 * @param delta of the line
**/
char ascii_re_route(char ascii)
{
	/* from space to 9 */
	if( (ascii >= 32)  && (ascii <= 96) )  return (ascii - 31);
	/* from a to z */
	if( (ascii >= 97)  && (ascii <= 122) ) return (ascii - 63);
	if( (ascii >= 123) && (ascii <= 126) ) return (ascii - 57);
	else return 0;
}


/**
 * Draw a single character
 * @param image to draw in
 * @param x where to start at
 * @param y where to start at
 * @param c Character to draw
 * @param color Color the character is drawn with
**/
void camcapture_draw_character(image_data_t *image, int x, int y, char c, color_rgb_t *color)
{
	int line, col, tmp;
	int Y, Cb, Cr;
	void *data;
	rgb_to_ycbcr(color, &Y, &Cb, &Cr);
	data = image->img;

	/* re-route ascii-values */
	c = ascii_re_route(c);
	/* non-existent-char */
	if(c >= CHAR_CNT) return;
	/* loop thru x */
	for(line = 0; line<CHAR_LINES; line++)
	{
		for(col = 0; col<CHAR_COLS; col++)
		{
			if( (chars[(int)c][line*CHAR_COLS+col]) != 1) continue;
			/* calculate y position into tmp */
			if((y+line) > image->height) break;
			tmp = (y+line)*image->width;
			/* calculate image position into tmp */
			if( (x+10) > image->width) break;
			tmp = (tmp + x) / 2 + col;
			if((tmp < 0) || (tmp > (image->height * image->width))) break;
			/* set pixel */
			*((int*)data+tmp) = 0 | (Y) | (Cb << 8) | (Y << 16) | (Cr << 24);
		}
	}
}



/**
 * Draw a string
 * @param image to draw in
 * @param x where to start at
 * @param y where to start at
 * @param str String to draw as char array ending with \0
 * @param color Color the character is drawn with
**/
void camcapture_draw_string(image_data_t *image, int x, int y, char *str, color_rgb_t *color)
{
	int n;
	for(n=0; str[n]!='\0'; n++)
	{
		camcapture_draw_character(image, x+(n*10), y, str[n], color);
	}
}
